==> pyg4ometry-1.1.2.tar.gz: pyg4ometry-1.1.2/tests/geant4/T432_MergeRegistry_Box_AssemblyConversion.py <==
import os as _os
import pathlib as _pl

import pyg4ometry.gdml as _gd
import pyg4ometry.geant4 as _g4
import pyg4ometry.visualisation as _vi

import T001_Box


def Test(vis=False, interactive=False, outputPath=None):
    if not outputPath:
        outputPath = _pl.Path(__file__).parent

    reg0 = _g4.Registry()

    l1 = T001_Box.Test(vis=False, interactive=False, outputPath=outputPath)["logicalVolume"]
    l2 = T001_Box.Test(vis=False, interactive=False, outputPath=outputPath)["logicalVolume"]
    av1 = l1.assemblyVolume()
    av2 = l2.assemblyVolume()

    wx0 = _gd.Constant("wx0", "200", reg0, True)
    wy0 = _gd.Constant("wy0", "200", reg0, True)
    wz0 = _gd.Constant("wz0", "200", reg0, True)

    wm = _g4.MaterialPredefined("G4_Galactic")
    ws = _g4.solid.Box("ws", wx0, wy0, wz0, reg0, "mm")
    wl = _g4.LogicalVolume(ws, wm, "world", reg0)

    p1 = _g4.PhysicalVolume([0, 0, 0], [-25, 0, 0], av1, "av1_pv", wl, reg0)
    p2 = _g4.PhysicalVolume([0, 0, 0], [25, 0, 0], av2, "av2_pv", wl, reg0)

    wl.checkOverlaps(recursive=True)

    reg0.addVolumeRecursive(p1)
    reg0.addVolumeRecursive(p2)

    reg0.setWorld(wl.name)

    # gdml output
    w = _gd.Writer()
    w.addDetector(reg0)
    w.write(outputPath / "T432_MergeRegistry_Box_AssemblyConversion.gdml")

    # test extent of physical volume
    extentBB = wl.extent(includeBoundingSolid=True)
    extent = wl.extent(includeBoundingSolid=False)

    # visualisation
    v = None
    if vis:
        v = _vi.VtkViewer()
        v.addLogicalVolume(reg0.getWorldVolume())
        v.addAxes(_vi.axesFromExtents(extentBB)[0])
        v.view(interactive=interactive)

    return {"testStatus": True, "logicalVolume": wl, "vtkViewer": v}


if __name__ == "__main__":
    Test()

==> pyg4ometry-1.3.2.tar.gz: pyg4ometry-1.3.2/tests/geant4/T432_MergeRegistry_Box_AssemblyConversion.py <==
import os as _os
import pathlib as _pl

import pyg4ometry.gdml as _gd
import pyg4ometry.geant4 as _g4
import pyg4ometry.visualisation as _vi
import pyg4ometry.misc as _mi

import T001_Box


def Test(vis=False, interactive=False, outputPath=None, refFilePath=None):
    if not outputPath:
        outputPath = _pl.Path(__file__).parent

    reg0 = _g4.Registry()

    l1 = T001_Box.Test(vis=False, interactive=False, outputPath=outputPath)["logicalVolume"]
    l2 = T001_Box.Test(vis=False, interactive=False, outputPath=outputPath)["logicalVolume"]
    av1 = l1.assemblyVolume()
    av2 = l2.assemblyVolume()

    wx0 = _gd.Constant("wx0", "200", reg0, True)
    wy0 = _gd.Constant("wy0", "200", reg0, True)
    wz0 = _gd.Constant("wz0", "200", reg0, True)

    wm = _g4.MaterialPredefined("G4_Galactic")
    ws = _g4.solid.Box("ws", wx0, wy0, wz0, reg0, "mm")
    wl = _g4.LogicalVolume(ws, wm, "world", reg0)

    p1 = _g4.PhysicalVolume([0, 0, 0], [-25, 0, 0], av1, "av1_pv", wl, reg0)
    p2 = _g4.PhysicalVolume([0, 0, 0], [25, 0, 0], av2, "av2_pv", wl, reg0)

    wl.checkOverlaps(recursive=True)

    reg0.addVolumeRecursive(p1)
    reg0.addVolumeRecursive(p2)

    reg0.setWorld(wl.name)

    # gdml output
    outputFile = outputPath / "T432_MergeRegistry_Box_AssemblyConversion.gdml"
    w = _gd.Writer()
    w.addDetector(reg0)
    w.write(outputFile)

    # check file
    _mi.compareGdmlNumericallyWithAssert(refFilePath, outputFile)

    # test extent of physical volume
    extentBB = wl.extent(includeBoundingSolid=True)
    extent = wl.extent(includeBoundingSolid=False)

    # visualisation
    v = None
    if vis:
        v = _vi.VtkViewer()
        v.addLogicalVolume(reg0.getWorldVolume())
        v.addAxes(_vi.axesFromExtents(extentBB)[0])
        v.view(interactive=interactive)

    return {"testStatus": True, "logicalVolume": wl, "vtkViewer": v}


if __name__ == "__main__":
    Test()
